(function() {
    class BubbleEffect {
        constructor() {
            this.bubbles = [];
            this.params = window.bubbleParams || {};
            this.init();
        }

        init() {
            document.addEventListener('mousemove', this.handleMouseMove.bind(this));
            requestAnimationFrame(this.animate.bind(this));
        }

        getRandomColor() {
            const colors = [
                this.params.color || '#FF3366',
                '#3366FF',
                '#33CC33',
                '#9933FF',
                '#FF6600',
                '#0099CC',
                '#FF3399'
            ];
            return colors[Math.floor(Math.random() * colors.length)];
        }

        handleMouseMove(e) {
            const newBubble = {
                id: Date.now(),
                x: e.clientX,
                y: e.clientY,
                size: Math.random() * (this.params.size || 10) + 5,
                color: this.getRandomColor(),
                angle: Math.random() * Math.PI * 2,
                speed: Math.random() * 2 + 1,
                lifetime: 100
            };

            this.bubbles.push(newBubble);
        }

        animate() {
            this.bubbles = this.bubbles
                .map(bubble => ({
                    ...bubble,
                    x: bubble.x + Math.cos(bubble.angle) * bubble.speed,
                    y: bubble.y - bubble.speed * 2,
                    size: bubble.size * 0.99,
                    lifetime: bubble.lifetime - 1
                }))
                .filter(bubble => bubble.lifetime > 0);

            this.render();
            requestAnimationFrame(this.animate.bind(this));
        }

        render() {
            // Remove old bubble elements
            document.querySelectorAll('.bubble-effect').forEach(el => {
                if (!this.bubbles.find(b => b.id === parseInt(el.dataset.id))) {
                    el.remove();
                }
            });

            // Update or create bubble elements
            this.bubbles.forEach(bubble => {
                let element = document.querySelector(`.bubble-effect[data-id="${bubble.id}"]`);
                
                if (!element) {
                    element = document.createElement('div');
                    element.className = 'bubble-effect';
                    element.dataset.id = bubble.id;
                    document.body.appendChild(element);
                }

                Object.assign(element.style, {
                    position: 'fixed',
                    left: `${bubble.x}px`,
                    top: `${bubble.y}px`,
                    width: `${bubble.size}px`,
                    height: `${bubble.size}px`,
                    backgroundColor: bubble.color,
                    borderRadius: '50%',
                    pointerEvents: 'none',
                    opacity: bubble.lifetime / 100,
                    boxShadow: '0 0 2px rgba(0,0,0,0.3)',
                    transform: 'translate(-50%, -50%)',
                    zIndex: 9999
                });
            });
        }
    }

    // Initialize the effect when the DOM is ready
    if (document.readyState === 'loading') {
        document.addEventListener('DOMContentLoaded', () => {
            new BubbleEffect();
        });
    } else {
        new BubbleEffect();
    }
    
    // Log initialization
    console.log('Bubble Effect Plugin Initialized');
})();